@@ -856,24 +856,17 @@ task_activated_cb (GtkTreeView       *view,
                    GtkTreeViewColumn *column,
                    ClockData         *cd)
 {
-        GtkTreeIter  iter;
-        GtkTreePath *child_path;
-        char        *uri;
+        GtkTreeIter iter;
+        char       *uri;
 
-        child_path = gtk_tree_model_filter_convert_path_to_child_path (cd->tasks_filter, path);
-
-        gtk_tree_model_get_iter (GTK_TREE_MODEL (cd->tasks_model), &iter, child_path);
+        gtk_tree_model_get_iter (GTK_TREE_MODEL (cd->tasks_model), &iter, path);
         gtk_tree_model_get (GTK_TREE_MODEL (cd->tasks_model), &iter,
                             TASK_COLUMN_URL, &uri, -1);
 
-        if (uri) {
+        if (uri)
                 gnome_url_show_on_screen (uri,
 					  gtk_widget_get_screen (cd->applet),
 					  NULL);
-        }
-
-        g_free (uri);
-        gtk_tree_path_free (child_path);
 
         return TRUE;
 }
@@ -1099,13 +1092,11 @@ handle_appointments_changed (ClockData *cd)
         guint   year, month, day;
 
         if (cd->calendar) {
-                gtk_calendar_freeze (GTK_CALENDAR (cd->calendar));
                 gtk_calendar_clear_marks (GTK_CALENDAR (cd->calendar));
 
                 calendar_client_foreach_appointment_day (cd->client,
                                                          (CalendarDayIter) mark_day_on_calendar,
                                                          cd);
-                gtk_calendar_thaw (GTK_CALENDAR (cd->calendar));
         }
 
         gtk_list_store_clear (cd->appointments_model);
@@ -1666,10 +1657,10 @@ create_clock_widget (ClockData *cd)
 	cd->orient = panel_applet_get_orient (PANEL_APPLET (cd->applet));
 
 	/* Initialize label orientation */
-	if (cd->orient == PANEL_APPLET_ORIENT_LEFT)
-		gtk_label_set_angle (GTK_LABEL (cd->clockw), 270);
-	else if (cd->orient == PANEL_APPLET_ORIENT_RIGHT)
+	if (cd->orient == PANEL_APPLET_ORIENT_RIGHT)
 		gtk_label_set_angle (GTK_LABEL (cd->clockw), 90);
+	else if (cd->orient == PANEL_APPLET_ORIENT_LEFT)
+		gtk_label_set_angle (GTK_LABEL (cd->clockw), 270);
 	else
 		gtk_label_set_angle (GTK_LABEL (cd->clockw), 0);
 
@@ -1695,10 +1686,10 @@ applet_change_orient (PanelApplet       *applet,
 {
         cd->orient = orient;
         
-        if (cd->orient == PANEL_APPLET_ORIENT_LEFT)
-                gtk_label_set_angle (GTK_LABEL (cd->clockw), 270);
-        else if (cd->orient == PANEL_APPLET_ORIENT_RIGHT)
+        if (cd->orient == PANEL_APPLET_ORIENT_RIGHT)
                 gtk_label_set_angle (GTK_LABEL (cd->clockw), 90);
+        else if (cd->orient == PANEL_APPLET_ORIENT_LEFT)
+                gtk_label_set_angle (GTK_LABEL (cd->clockw), 270);
         else
                 gtk_label_set_angle (GTK_LABEL (cd->clockw), 0);
 	
