@@ -10,7 +10,8 @@
 #include <string.h>
 #include <signal.h>
 #include <unistd.h>
-#include <libbonobo.h>
+
+#include <glib/gi18n.h>
 #include <gdk/gdkx.h>
 
 #include "button-widget.h"
@@ -603,7 +604,8 @@ panel_applet_position_menu (GtkMenu   *menu,
 	}
 
 	if (PANEL_WIDGET (applet->parent)->orient == GTK_ORIENTATION_HORIZONTAL) {
-		if (requisition.width < pointer_x)
+		if (pointer_x < applet->allocation.width &&
+		    requisition.width < pointer_x)
 			menu_x += MIN (pointer_x, applet->allocation.width - requisition.width);
 		menu_x = MIN (menu_x, gdk_screen_get_width (screen) - requisition.width);
 
@@ -612,7 +614,8 @@ panel_applet_position_menu (GtkMenu   *menu,
 		else
 			menu_y += applet->allocation.height;
 	} else {
-		if (requisition.height < pointer_y)
+		if (pointer_y < applet->allocation.height &&
+		    requisition.height < pointer_y)
 			menu_y += MIN (pointer_y, applet->allocation.height - requisition.height);
 		menu_y = MIN (menu_y, gdk_screen_get_height (screen) - requisition.height);
 
@@ -1264,7 +1267,6 @@ panel_applet_get_position (AppletInfo *applet)
 gboolean
 panel_applet_can_freely_move (AppletInfo *applet)
 {
-	PanelWidget       *panel_widget;
 	GConfClient       *client;
 	PanelGConfKeyType  key_type;
 	const char        *key;
@@ -1272,8 +1274,6 @@ panel_applet_can_freely_move (AppletInfo *applet)
 	if (panel_lockdown_get_locked_down ())
 		return FALSE;
 
-	panel_widget = PANEL_WIDGET (applet->widget->parent);
-
 	client  = panel_gconf_get_client ();
 	
 	key_type = (applet->type == PANEL_OBJECT_BONOBO) ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
@@ -1297,15 +1297,12 @@ gboolean
 panel_applet_lockable (AppletInfo *applet)
 {
 	GConfClient        *client;
-	PanelWidget        *panel_widget;
 	PanelGConfKeyType   key_type;
 	const char         *key;
 
 	if (panel_lockdown_get_locked_down ())
 		return FALSE;
 	
-	panel_widget = PANEL_WIDGET (applet->widget->parent);
-
 	client  = panel_gconf_get_client ();
 	
 	key_type = (applet->type == PANEL_OBJECT_BONOBO) ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
