@@ -29,6 +29,7 @@
 #include <gtk/gtkenums.h>
 #include <gtk/gtkeventbox.h>
 #include <libgnomeui/gnome-ui-init.h>
+#include <libgnomeui/gnome-client.h>
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-ui-component.h>
 #include <bonobo/bonobo-generic-factory.h>
@@ -62,7 +63,7 @@ typedef enum {
 	PANEL_APPLET_FLAGS_NONE   = 0,
 	PANEL_APPLET_EXPAND_MAJOR = 1 << 0,
 	PANEL_APPLET_EXPAND_MINOR = 1 << 1,
-	PANEL_APPLET_HAS_HANDLE   = 1 << 2,
+	PANEL_APPLET_HAS_HANDLE   = 1 << 2
 } PanelAppletFlags;
 
 typedef struct _PanelApplet        PanelApplet;
@@ -125,6 +126,11 @@ void      	   panel_applet_set_size_hints       (PanelApplet      *applet,
 						      int               n_elements,
 						      int               base_size);
 
+gboolean           panel_applet_get_locked_down      (PanelApplet  *applet);
+
+void               panel_applet_request_focus        (PanelApplet  *applet,
+						      guint32       timestamp);
+
 BonoboControl     *panel_applet_get_control          (PanelApplet  *applet);
 BonoboUIComponent *panel_applet_get_popup_component  (PanelApplet  *applet);
 
@@ -169,10 +175,38 @@ Bonobo_Unknown	   panel_applet_shlib_factory_closure (const char
  * These macros are getting a bit unwieldy.
  *
  * Things to define for these:
- *	+ required : GETTEXT_PACKAGE and GNOMELOCALEDIR.
+ *	+ required if Native Language Support is enabled (ENABLE_NLS):
+ *                   GETTEXT_PACKAGE and GNOMELOCALEDIR 
  *      + optional : PREFIX, SYSCONFDIR, DATADIR and LIBDIR.
  */
 
+#if !defined(ENABLE_NLS)
+#if defined(PREFIX) && defined(SYSCONFDIR) && defined(DATADIR) && defined(LIBDIR)
+#define PANEL_APPLET_BONOBO_FACTORY(iid, type, name, version, callback, data)	\
+int main (int argc, char *argv [])						\
+{										\
+	gnome_program_init (name, version,					\
+			    LIBGNOMEUI_MODULE,					\
+			    argc, argv,						\
+			    GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,               \
+			    GNOME_PROGRAM_STANDARD_PROPERTIES,			\
+			    NULL);						\
+        return panel_applet_factory_main (iid, type, callback, data);		\
+}
+#else /* !defined(PREFIX) ... */
+#define PANEL_APPLET_BONOBO_FACTORY(iid, type, name, version, callback, data)	\
+int main (int argc, char *argv [])						\
+{										\
+	gnome_program_init (name, version,					\
+			    LIBGNOMEUI_MODULE,					\
+			    argc, argv,						\
+			    GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,               \
+			    GNOME_PARAM_NONE);					\
+        return panel_applet_factory_main (iid, type, callback, data);		\
+}
+#endif /* defined(PREFIX) ... */
+#else /* defined(ENABLE_NLS) */
+#include <libintl.h>
 #if defined(PREFIX) && defined(SYSCONFDIR) && defined(DATADIR) && defined(LIBDIR)
 #define PANEL_APPLET_BONOBO_FACTORY(iid, type, name, version, callback, data)	\
 int main (int argc, char *argv [])						\
@@ -183,11 +217,12 @@ int main (int argc, char *argv [])						\
 	gnome_program_init (name, version,					\
 			    LIBGNOMEUI_MODULE,					\
 			    argc, argv,						\
+			    GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,               \
 			    GNOME_PROGRAM_STANDARD_PROPERTIES,			\
 			    NULL);						\
         return panel_applet_factory_main (iid, type, callback, data);		\
 }
-#else
+#else /* !defined(PREFIX) ... */
 #define PANEL_APPLET_BONOBO_FACTORY(iid, type, name, version, callback, data)	\
 int main (int argc, char *argv [])						\
 {										\
@@ -197,11 +232,31 @@ int main (int argc, char *argv [])						\
 	gnome_program_init (name, version,					\
 			    LIBGNOMEUI_MODULE,					\
 			    argc, argv,						\
+			    GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,               \
 			    GNOME_PARAM_NONE);					\
         return panel_applet_factory_main (iid, type, callback, data);		\
 }
-#endif
+#endif /* defined(PREFIX) ... */
+#endif /* !defined(ENABLE_NLS) */
 
+#if !defined(ENABLE_NLS)
+#define PANEL_APPLET_BONOBO_SHLIB_FACTORY(iid, type, descr, callback, data)	\
+static Bonobo_Unknown								\
+__panel_applet_shlib_factory (PortableServer_POA  poa,				\
+			      const char         *oafiid,			\
+			      gpointer            impl_ptr,			\
+			      CORBA_Environment  *ev)				\
+{										\
+        return panel_applet_shlib_factory ((iid), (type), poa, impl_ptr,	\
+					   (callback), (data), ev);		\
+}										\
+static BonoboActivationPluginObject plugin_list[] = {				\
+	{ (iid), __panel_applet_shlib_factory },				\
+	{ NULL }								\
+};										\
+const  BonoboActivationPlugin Bonobo_Plugin_info = { plugin_list, (descr) };
+#else /* defined(ENABLE_NLS) */
+#include <libintl.h>
 #define PANEL_APPLET_BONOBO_SHLIB_FACTORY(iid, type, descr, callback, data)	\
 static Bonobo_Unknown								\
 __panel_applet_shlib_factory (PortableServer_POA  poa,				\
@@ -211,7 +266,6 @@ __panel_applet_shlib_factory (PortableServer_POA  poa,				\
 {										\
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);			\
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");			\
-	textdomain (GETTEXT_PACKAGE);						\
         return panel_applet_shlib_factory ((iid), (type), poa, impl_ptr,	\
 					   (callback), (data), ev);		\
 }										\
@@ -220,6 +274,7 @@ static BonoboActivationPluginObject plugin_list[] = {				\
 	{ NULL }								\
 };										\
 const  BonoboActivationPlugin Bonobo_Plugin_info = { plugin_list, (descr) };
+#endif /* !defined(ENABLE_NLS) */
 
 G_END_DECLS
 
